Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(129)

Unified Diff: net/third_party/nss/ssl/sslinfo.c

Issue 10542176: SSL_GetChannelInfo and SSL_GetNegotiatedHostInfo should use (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Add the upstream NSS bug number Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/third_party/nss/patches/getchannelinfo.patch ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/third_party/nss/ssl/sslinfo.c
===================================================================
--- net/third_party/nss/ssl/sslinfo.c (revision 142907)
+++ net/third_party/nss/ssl/sslinfo.c (working copy)
@@ -97,11 +97,11 @@
} else if (ss->ssl3.initialized) { /* SSL3 and TLS */
ssl_GetSpecReadLock(ss);
/* XXX The cipher suite should be in the specs and this
* function should get it from crSpec rather than from the "hs".
* See bug 275744 comment 69.
*/
inf.cipherSuite = ss->ssl3.hs.cipher_suite;
- inf.compressionMethod = ss->ssl3.crSpec->compression_method;
+ inf.compressionMethod = ss->ssl3.cwSpec->compression_method;
ssl_ReleaseSpecReadLock(ss);
inf.compressionMethodName =
ssl_GetCompressionMethodName(inf.compressionMethod);
@@ -336,7 +336,7 @@
ss->ssl3.initialized) { /* TLS */
SECItem *crsName;
ssl_GetSpecReadLock(ss); /*********************************/
- crsName = &ss->ssl3.crSpec->srvVirtName;
+ crsName = &ss->ssl3.cwSpec->srvVirtName;
if (crsName->data) {
sniName = SECITEM_DupItem(crsName);
}
@@ -97,11 +97,11 @@
ssl_GetSpecReadLock(ss);
/* XXX The cipher suite should be in the specs and this
- * function should get it from crSpec rather than from the "hs".
+ * function should get it from cwSpec rather than from the "hs".
* See bug 275744 comment 69.
*/
« no previous file with comments | « net/third_party/nss/patches/getchannelinfo.patch ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698